@@ -44,6 +44,7 @@ __all__ = [
     'get_plugin_config',
     'get_plugin_boolean_config',
     'get_plugin_int_config',
+    'is_enabled',
     'git_enabled',
     'get_root_folder',
     'git_absolute_path',
@@ -92,6 +93,11 @@ def get_plugin_int_config(key: str) -> int:
     )  # type: ignore
 
 
+def is_enabled() -> bool:
+    "Return true if the plugin is enabled in the configuration"
+    return get_plugin_boolean_config('enabled')
+
+
 def git_enabled() -> bool:
     "Return true if git is enabled in the configuration"
     return get_plugin_boolean_config('git_enabled')
